<?php
/**
 * Media Feed
 * 
 * @package    MediaFeed
 * @subpackage MediaFeed registered in the database
    Copyright (c) 2017- Katsushi Kawamori (email : dodesyoswift312@gmail.com)
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; version 2 of the License.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/

$mediafeedregist = new MediaFeedRegist();

class MediaFeedRegist {

	/* ==================================================
	 * Construct
	 * @since	1.07
	 */
	public function __construct() {

		add_action( 'admin_init', array($this, 'register_settings') );

	}

	/* ==================================================
	 * Settings register
	 * @since	1.0
	 */
	function register_settings(){

		$apply_media = TRUE;
		$apply_image = TRUE;
		$apply_audio = TRUE;
		$apply_video = TRUE;
		$apply_misc = TRUE;
		$text_media = __('Media');
		$text_image = __('Image');
		$text_audio = __('Audio');
		$text_video = __('Video');
		$text_misc = __('Misc', 'media-feed');
		$per_rss_media = intval(get_option('posts_per_rss'));
		$per_rss_image = intval(get_option('posts_per_rss'));
		$per_rss_audio = intval(get_option('posts_per_rss'));
		$per_rss_video = intval(get_option('posts_per_rss'));
		$per_rss_misc = intval(get_option('posts_per_rss'));
		$exclude_id = NULL;
		$term_filter = NULL;

		if ( get_option('media_feed_options') ) {
			$media_feed_options = get_option('media_feed_options');
			if ( array_key_exists( "media", $media_feed_options["apply"] ) ) {
				$apply_media = $media_feed_options['apply']['media'];
			}
			if ( array_key_exists( "image", $media_feed_options["apply"] ) ) {
				$apply_image = $media_feed_options['apply']['image'];
			}
			if ( array_key_exists( "audio", $media_feed_options["apply"] ) ) {
				$apply_audio = $media_feed_options['apply']['audio'];
			}
			if ( array_key_exists( "video", $media_feed_options["apply"] ) ) {
				$apply_video = $media_feed_options['apply']['video'];
			}
			if ( array_key_exists( "misc", $media_feed_options["apply"] ) ) {
				$apply_misc = $media_feed_options['apply']['misc'];
			}
			if ( array_key_exists( "media", $media_feed_options["text"] ) ) {
				$text_media = $media_feed_options['text']['media'];
			}
			if ( array_key_exists( "image", $media_feed_options["text"] ) ) {
				$text_image = $media_feed_options['text']['image'];
			}
			if ( array_key_exists( "audio", $media_feed_options["text"] ) ) {
				$text_audio = $media_feed_options['text']['audio'];
			}
			if ( array_key_exists( "video", $media_feed_options["text"] ) ) {
				$text_video = $media_feed_options['text']['video'];
			}
			if ( array_key_exists( "misc", $media_feed_options["text"] ) ) {
				$text_misc = $media_feed_options['text']['misc'];
			}
			if ( array_key_exists( "media", $media_feed_options["per_rss"] ) ) {
				$per_rss_media = $media_feed_options['per_rss']['media'];
			}
			if ( array_key_exists( "image", $media_feed_options["per_rss"] ) ) {
				$per_rss_image = $media_feed_options['per_rss']['image'];
			}
			if ( array_key_exists( "audio", $media_feed_options["per_rss"] ) ) {
				$per_rss_audio = $media_feed_options['per_rss']['audio'];
			}
			if ( array_key_exists( "video", $media_feed_options["per_rss"] ) ) {
				$per_rss_video = $media_feed_options['per_rss']['video'];
			}
			if ( array_key_exists( "misc", $media_feed_options["per_rss"] ) ) {
				$per_rss_misc = $media_feed_options['per_rss']['misc'];
			}
			if ( array_key_exists( "exclude_id", $media_feed_options ) ) {
				$exclude_id = $media_feed_options['exclude_id'];
			}
			if ( array_key_exists( "term_filter", $media_feed_options ) ) {
				$term_filter = $media_feed_options['term_filter'];
			}
		}

		$media_feed_options = array(
							'apply'		=> array(
											'media' => $apply_media,
											'image' => $apply_image,
											'audio' => $apply_audio,
											'video' => $apply_video,
											'misc' => $apply_misc
											),
							'text'		=> array(
											'media' => $text_media,
											'image' => $text_image,
											'audio' => $text_audio,
											'video' => $text_video,
											'misc' => $text_misc
											),
							'per_rss'	=> array(
											'media' => $per_rss_media,
											'image' => $per_rss_image,
											'audio' => $per_rss_audio,
											'video' => $per_rss_video,
											'misc' => $per_rss_misc
										),
							'exclude_id' => $exclude_id,
							'term_filter' => $term_filter
							);

		update_option( 'media_feed_options', $media_feed_options );

		$media_feed_link = get_feed_link('media');
		$image_feed_link = get_feed_link('image');
		$audio_feed_link = get_feed_link('audio');
		$video_feed_link = get_feed_link('video');
		$misc_feed_link = get_feed_link('misc');
		$media_feed_widget = array(
								'media' => $media_feed_link,
								'image' => $image_feed_link,
								'audio' => $audio_feed_link,
								'video' => $video_feed_link,
								'misc' => $misc_feed_link
							);
		update_option( 'media_feed_widget', $media_feed_widget );

	}

}

?>